pub(super) enum MasterkeyUnlockMethod {
Password {
password: String,
hint: Option<String>,
kdf: Kdf,
salt: String,
},
KeyConnector,
None,
}Expand description
The unlock method that uses the master-key field on the user’s account. This can be either the master password, or the key-connector. For TDE users without a master password, this field is empty.
Variants
Password
The master password based unlock method.
KeyConnector
The key-connector based unlock method. NOTE: THIS IS NOT SUPPORTED YET AND WILL PANIC IF USED
None
No master-key based unlock method. This is TDE users without a master password. NOTE: THIS IS NOT SUPPORTED YET AND WILL PANIC IF USED